@@ -1,12 +1,14 @@
 import typing
 
-from zero_play.connect4.game import Connect4Game
+from zero_play.connect4.game import Connect4State
 from zero_play.grid_display import GridDisplay, GraphicsPieceItem
 
 
 class Connect4Display(GridDisplay):
+    rules_path = ':/zero_play_rules/connect4.md'
+
     def __init__(self):
-        super().__init__(Connect4Game())
+        super().__init__(Connect4State())
 
     def calculate_move(self, row, column):
         return column
