@@ -9,7 +9,7 @@ from random import shuffle
 import numpy as np
 from PySide2.QtCore import QSettings, QFile, QTextStream
 
-from PySide2.QtGui import QResizeEvent, Qt
+from PySide2.QtGui import Qt, QIcon, QPixmap
 from PySide2.QtWidgets import (QApplication, QMainWindow, QFileDialog,
                                QTableWidgetItem, QGridLayout, QPushButton,
                                QSizePolicy, QDialog, QWidget, QLabel, QComboBox)
@@ -19,15 +19,16 @@ import zero_play
 from zero_play.about_dialog import Ui_Dialog
 from zero_play.game_state import GameState
 from zero_play.game_display import GameDisplay
-from zero_play.grid_display import GridDisplay
 from zero_play.main_window import Ui_MainWindow
 from zero_play.mcts_player import MctsPlayer
 from zero_play.playout import Playout
 from zero_play.rules_formatter import convert_markdown
 from zero_play.strength_adjuster import StrengthAdjuster
 from zero_play import zero_play_rules_rc
+from zero_play import zero_play_images_rc
 
 assert zero_play_rules_rc  # Need to import this module to load resources.
+assert zero_play_images_rc  # Need to import this module to load resources.
 
 try:
     from zero_play.plot_canvas import PlotCanvas
@@ -44,10 +45,13 @@ class AboutDialog(QDialog):
         self.ui.setupUi(self)
         self.ui.version.setText(zero_play.__version__)
         credits_layout = self.ui.credits_layout
-        for title, text in credit_pairs:
-            row = credits_layout.rowCount()
+        row = 0
+        for row, (title, text) in enumerate(credit_pairs):
             credits_layout.addWidget(QLabel(title), row, 0, Qt.AlignRight)
             credits_layout.addWidget(QLabel(text), row, 1)
+        row += 1
+        credits_layout.addWidget(self.ui.version_label, row, 0)
+        credits_layout.addWidget(self.ui.version, row, 1)
 
 
 def get_settings(game_state: GameState = None):
@@ -65,6 +69,8 @@ class ZeroPlayWindow(QMainWindow):
     To create your own collection, declare a sub class, and override these
     methods: get_collection_name(), filter_games().
     """
+    icon_path = ":/zero_play_images/main_icon.png"
+
     def __init__(self):
         super().__init__()
         self.setAttribute(Qt.WA_DeleteOnClose, True)
@@ -92,8 +98,11 @@ class ZeroPlayWindow(QMainWindow):
         self.is_history_dirty = False  # Has current game been rewound?
         self.all_displays = []
         self.load_game_list(ui.game_page.layout())
+        icon_pixmap = QPixmap(self.icon_path)  # After displays load resources!
+        icon = QIcon(icon_pixmap)
+        self.setWindowIcon(icon)
         self.start_state = None
-        self.display: typing.Optional[GridDisplay] = None
+        self.display: typing.Optional[GameDisplay] = None
         self.on_new_game()
         self.board_to_resume: typing.Optional[np.ndarray] = None
         self.review_names = [name.strip()
@@ -116,6 +125,7 @@ class ZeroPlayWindow(QMainWindow):
         credit_pairs = chain(*(display.credit_pairs
                                for display in self.all_displays))
         dialog = AboutDialog(credit_pairs, self)
+        dialog.setWindowTitle(f'About {self.get_collection_name()}')
         dialog.exec_()
 
     def load_game_list(self, game_layout: QGridLayout):
@@ -186,8 +196,9 @@ class ZeroPlayWindow(QMainWindow):
         self.ui.move_history.setVisible(is_review_visible)
         self.ui.choices.setVisible(is_review_visible)
         self.ui.toggle_review.setText(self.review_names[is_review_visible])
+        if self.display is not None:
+            self.display.is_reviewing = is_review_visible
         choices.setVisible(is_review_visible)
-        self.resize_display()
 
     def on_resume_here(self):
         self.board_to_resume = self.display.current_state
@@ -218,10 +229,9 @@ class ZeroPlayWindow(QMainWindow):
 
     def on_new_game(self):
         if self.display is not None:
-            self.display.close()
+            self.display.stop_workers()
             self.display = None
         self.ui.stacked_widget.setCurrentWidget(self.ui.game_page)
-        self.ui.action_view_game.setChecked(True)
         self.setWindowTitle(self.get_collection_name())
 
     def show_game(self, display: GameDisplay):
@@ -334,31 +344,19 @@ class ZeroPlayWindow(QMainWindow):
             for player_number, (heuristic, searches) in mcts_choices.items()
             if heuristic is not None]
         layout: QGridLayout = ui.display_page.layout()
-        layout.removeWidget(ui.display_view)
-        ui.display_view.setVisible(False)
+        layout.replaceWidget(ui.game_display, self.display)
+        ui.game_display.setVisible(False)
+        ui.game_display = self.display
         self.display.setVisible(True)
-        ui.display_view = self.display
-        layout.addWidget(self.display, 0, 0, 1, 3)
         self.display.show_coordinates = ui.action_coordinates.isChecked()
 
         self.on_view_game()
 
-    def resizeEvent(self, event: QResizeEvent):
-        super().resizeEvent(event)
-        self.resize_display()
-
-    def resize_display(self):
-        if self.display is None:
-            return
-        size = self.ui.display_view.maximumViewportSize()
-        self.display.resize(size)
-
     def on_view_game(self):
         if self.display is None:
             self.on_new_game()
         else:
             self.ui.stacked_widget.setCurrentWidget(self.ui.display_page)
-            self.resize_display()
             self.display.update_board(self.display.current_state)
             self.display.request_move()
 
